#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Python Cursor on Target Module Exceptions."""

__author__ = 'Greg Albrecht <oss@undef.net>'
__copyright__ = 'Copyright 2020 Orion Labs, Inc.'
__license__ = 'Apache License, Version 2.0'


class UnsupportedEvent(Exception):
    """Unsupported CoT Event."""
    pass
